# Changelog

## [0.1.11] - 2025-03-18

- Version bump

## [0.1.9] - 2025-03-18

- Version bump

## [0.1.8] - 2025-03-18

- Version bump

## [0.1.7] - 2025-03-18

- Version bump

## [0.1.4] - 2025-03-18

- Version bump

## [0.1.6] - 2025-03-18

### Added
- Auto-updated version


## [0.1.5] - 2025-03-18

### Added
- Auto-updated version


## [0.1.4] - 2025-03-18

### Added
- Auto-updated version


## [0.1.3] - 2025-03-18

### Added
- Auto-updated version


## [0.1.2] - 2025-03-18

### Added
- Auto-updated version


## [0.1.1] - 2025-03-18

### Added
- Auto-updated version


All notable changes to this project will be documented in this file.

## [0.1.0] - 2025-03-18

### Added
- Initial package structure
- Basic project setup with src layout
- Publishing scripts 